# Table of Contents

- [application-total-cost-of-ownership-extension](<./application-total-cost-of-ownership-extension.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Application Total Cost of Ownership (TCO) Extension](<./Application-Total-Cost-of-Ownership-TCO-Extension.md>)
  - [Overview](<./Application-Total-Cost-of-Ownership-TCO-Extension/Overview.md>)
  - [Activating the Extension](<./Application-Total-Cost-of-Ownership-TCO-Extension/Activating-the-Extension.md>)
  - [Meta Model Additions](<./Application-Total-Cost-of-Ownership-TCO-Extension/Meta-Model-Additions.md>)
